==> minitube-src-0.1.tar.gz: minitube/src/synchttp.cpp <==
#include "synchttp.h"

SyncHttp::SyncHttp( QObject* parent ) : QObject( parent ) {
    http = new QHttp(this);
    connect(http, SIGNAL(responseHeaderReceived(const QHttpResponseHeader &)),
            this, SLOT(readResponseHeader(const QHttpResponseHeader &)));
    connect(http, SIGNAL(requestFinished(int, bool)), this, SLOT(requestFinished(int, bool)));
    httpRequestId = -1;
    httpActive = false;
    httpBuffer = new QBuffer(this);
}

QByteArray SyncHttp::getBytes(QUrl url) {
    httpActive = true;

    QHttp::ConnectionMode mode = url.scheme().toLower() == "https" ?
                                 QHttp::ConnectionModeHttps : QHttp::ConnectionModeHttp;
    http->setHost(url.host(), mode, url.port() == -1 ? 0 : url.port());
    QHttpRequestHeader header("GET", url.path() + "?" + url.encodedQuery());
    header.setValue("Host", url.host());
    // header.setValue("User-Agent", "Minitube (http://flavio.tordini.org/minitube)");
    header.setValue("Accept", "*/*");
    header.setValue("Connection", "Keep-Alive");

    // if (httpBuffer) delete httpBuffer;

    // FIXME leak!
    httpBuffer = new QBuffer(this);
    if (!httpBuffer->open(QBuffer::ReadWrite)) {
        qDebug("Cannot open buffer");
    }
    qDebug() << "GET " << url.toEncoded();
    httpRequestId = http->request(header, 0, httpBuffer);

    // A little trick to make this function blocking
    while (httpActive) {
        // Do something else, maybe even network processing events
        qApp->processEvents();
    }

    httpBuffer->deleteLater();
    return httpBuffer->buffer();
}

QString SyncHttp::get(QUrl url) {
    return QString::fromUtf8(getBytes(url));
}

void SyncHttp::requestFinished(int requestId, bool error) {
    if (requestId != this->httpRequestId) return;
    if (error) {
        qDebug() << http->errorString().toUtf8();
    }
    // qDebug() << "httpActive=false";
    httpActive = false;
}

void SyncHttp::readResponseHeader(const QHttpResponseHeader & /* responseHeader */) {
    noHeaders = false;
}

QHttpResponseHeader SyncHttp::head(QUrl url) {
    noHeaders = true;

    qDebug() << "HEAD " << url.path() + "?" + url.encodedQuery();

    QHttp::ConnectionMode mode = url.scheme().toLower() == "https" ?
                                 QHttp::ConnectionModeHttps : QHttp::ConnectionModeHttp;
    http->setHost(url.host(), mode, url.port() == -1 ? 0 : url.port());
    QHttpRequestHeader header("HEAD", url.path() + "?" + url.encodedQuery());
    header.setValue("Host", url.host());
    // header.setValue("User-Agent", "Minitube (http://flavio.tordini.org/minitube)");
    header.setValue("User-Agent", "curl/7.18.2 (i486-pc-linux-gnu) libcurl/7.18.2 OpenSSL/0.9.8g zlib/1.2.3.3 libidn/1.8");
    header.setValue("Accept", "*/*");
    header.setValue("Connection", "Keep-Alive");
    httpRequestId = http->request(header, 0, 0);

    // A little trick to make this function blocking
    while (noHeaders) {
        // Do something else, maybe even network processing events
        qApp->processEvents();
    }

    return http->lastResponse();
}

==> minitube-src-0.2.1.tar.gz: minitube/src/synchttp.cpp <==
#include "synchttp.h"
#include "Constants.h"

SyncHttp::SyncHttp( QObject* parent) : QObject( parent ) {
    http = new QHttp(this);
    connect(http, SIGNAL(responseHeaderReceived(const QHttpResponseHeader &)),
            this, SLOT(readResponseHeader(const QHttpResponseHeader &)));
    connect(http, SIGNAL(requestFinished(int, bool)), this, SLOT(requestFinished(int, bool)));
    httpRequestId = -1;
    httpActive = false;
    httpBuffer = new QBuffer(this);
}

QByteArray SyncHttp::getBytes(QUrl url) {
    httpActive = true;

    QHttp::ConnectionMode mode = url.scheme().toLower() == "https" ?
                                 QHttp::ConnectionModeHttps : QHttp::ConnectionModeHttp;
    http->setHost(url.host(), mode, url.port() == -1 ? 0 : url.port());
    QString path = url.path();
    if (url.hasQuery())
        path += "?" + url.encodedQuery();
    QHttpRequestHeader header("GET", path);
    header.setValue("Host", url.host());
    header.setValue("User-Agent", QString(Constants::APP_NAME) + " " +
                    Constants::VERSION + " (" + Constants::WEBSITE + ")");
    header.setValue("Accept", "*/*");
    header.setValue("Connection", "Keep-Alive");

    // if (httpBuffer) delete httpBuffer;

    // FIXME leak!
    httpBuffer = new QBuffer(this);
    if (!httpBuffer->open(QBuffer::ReadWrite)) {
        qDebug("Cannot open buffer");
    }
    qDebug() << "GET " << url.toEncoded();
    httpRequestId = http->request(header, 0, httpBuffer);

    // A little trick to make this function blocking
    while (httpActive) {
        // Do something else, maybe even network processing events
        qApp->processEvents();
    }

    httpBuffer->deleteLater();
    return httpBuffer->buffer();
}

QString SyncHttp::get(QUrl url) {
    return QString::fromUtf8(getBytes(url));
}

void SyncHttp::requestFinished(int requestId, bool error) {
    if (requestId != this->httpRequestId) return;
    if (error) {
        qDebug() << http->errorString().toUtf8();
    }
    // qDebug() << "httpActive=false";
    httpActive = false;
}

void SyncHttp::readResponseHeader(const QHttpResponseHeader & /* responseHeader */) {
    noHeaders = false;
}

QHttpResponseHeader SyncHttp::head(QUrl url) {
    noHeaders = true;

    qDebug() << "HEAD " << url.path() + "?" + url.encodedQuery();

    QHttp::ConnectionMode mode = url.scheme().toLower() == "https" ?
                                 QHttp::ConnectionModeHttps : QHttp::ConnectionModeHttp;
    http->setHost(url.host(), mode, url.port() == -1 ? 0 : url.port());
    QHttpRequestHeader header("HEAD", url.path() + "?" + url.encodedQuery());
    header.setValue("Host", url.host());
    header.setValue("User-Agent", QString(Constants::APP_NAME) + " " +
                    Constants::VERSION + " (" + Constants::WEBSITE + ")");
    header.setValue("Accept", "*/*");
    header.setValue("Connection", "Keep-Alive");
    httpRequestId = http->request(header, 0, 0);

    // A little trick to make this function blocking
    while (noHeaders) {
        // Do something else, maybe even network processing events
        qApp->processEvents();
    }

    return http->lastResponse();
}
